@@ -6,14 +6,17 @@ Created on Thu Aug 27 08:37:50 2020
 @author: oscar
 """
 
-import pandas as pd
-import matplotlib.pyplot as plt
 from copy import deepcopy
-from textblob import TextBlob
+
+import matplotlib.pyplot as plt
+import pandas as pd
+
 # from wj_analysis.common.nlp_utils import Polarity as pol_dist
 import plotly.graph_objects as go
+
 # import plotly.express as px
 from numpy import arange, mean
+from textblob import TextBlob
 
 pd.options.mode.chained_assignment = None
 
@@ -68,7 +71,9 @@ def find_point(df_p, carac="."):
 DF_FILTER_1["Pos"] = find_point(df_p=DF_FILTER_1, carac=".")
 
 for i in range(len(DF_FILTER_1)):
-    plt.plot(range(len(DF_FILTER_1.Pos.iloc[i])), DF_FILTER_1.Pos.iloc[i], "o-", label=str(i))
+    plt.plot(
+        range(len(DF_FILTER_1.Pos.iloc[i])), DF_FILTER_1.Pos.iloc[i], "o-", label=str(i)
+    )
 plt.title("Longitud de los textos palabra " + str(WORDS[0]))
 plt.legend()
 plt.show()
@@ -134,29 +139,39 @@ fig = go.Figure(
             x=num_phrase,
             y=pol,
             text=text_split,
-            mode='markers',
+            mode="markers",
             marker=dict(
                 color=len_text,
                 size=size_point,
                 showscale=True,
-                line=dict(width=2, color='MediumPurple'),
+                line=dict(width=2, color="MediumPurple"),
                 colorbar=dict(
                     title="Tamaño frase",
-                    tickvals=[min(len_text), mean(len_text),
-                              max(len_text)],
-                    ticktext=["Bajo", "Promedio", "Alto"]),
-                colorscale="Blues"),
+                    tickvals=[min(len_text), mean(len_text), max(len_text)],
+                    ticktext=["Bajo", "Promedio", "Alto"],
+                ),
+                colorscale="Blues",
+            ),
         )
-    ])
+    ]
+)
 
 fig.update_traces(mode="markers+lines")
 fig.update_layout(
-    title=str(DF_FILTER_1.title.iloc[text] + \
-              ", tamaño total texto " + \
-                  str(round(sum(len_text) * scale, 0))),
+    title=str(
+        DF_FILTER_1.title.iloc[text]
+        + ", tamaño total texto "
+        + str(round(sum(len_text) * scale, 0))
+    ),
     xaxis=dict(title="Frase"),
-    yaxis=dict(title="Polaridad, " + "(promedio " + \
-               str(round(mean(pol), 2)) + ")" + " (rango " +\
-                   str(round((max(pol) - min(pol)), 2)) + ")")
-    )
+    yaxis=dict(
+        title="Polaridad, "
+        + "(promedio "
+        + str(round(mean(pol), 2))
+        + ")"
+        + " (rango "
+        + str(round((max(pol) - min(pol)), 2))
+        + ")"
+    ),
+)
 fig.show()
